# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/stt/v2/stt_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/stt/v2/stt_service.proto',
  package='yandex.cloud.ai.stt.v2',
  syntax='proto3',
  serialized_options=b'\n\032yandex.cloud.api.ai.stt.v2Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v2;stt',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(yandex/cloud/ai/stt/v2/stt_service.proto\x12\x16yandex.cloud.ai.stt.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\"\x93\x01\n\x1dLongRunningRecognitionRequest\x12\x39\n\x06\x63onfig\x18\x01 \x01(\x0b\x32).yandex.cloud.ai.stt.v2.RecognitionConfig\x12\x37\n\x05\x61udio\x18\x02 \x01(\x0b\x32(.yandex.cloud.ai.stt.v2.RecognitionAudio\"a\n\x1eLongRunningRecognitionResponse\x12?\n\x06\x63hunks\x18\x01 \x03(\x0b\x32/.yandex.cloud.ai.stt.v2.SpeechRecognitionResult\"\x88\x01\n\x1bStreamingRecognitionRequest\x12;\n\x06\x63onfig\x18\x01 \x01(\x0b\x32).yandex.cloud.ai.stt.v2.RecognitionConfigH\x00\x12\x17\n\raudio_content\x18\x02 \x01(\x0cH\x00\x42\x13\n\x11streaming_request\"}\n\x1cStreamingRecognitionResponse\x12>\n\x06\x63hunks\x18\x01 \x03(\x0b\x32..yandex.cloud.ai.stt.v2.SpeechRecognitionChunkJ\x04\x08\x02\x10\x03R\x17\x65nd_of_single_utterance\"D\n\x10RecognitionAudio\x12\x11\n\x07\x63ontent\x18\x01 \x01(\x0cH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x42\x0e\n\x0c\x61udio_source\"f\n\x11RecognitionConfig\x12>\n\rspecification\x18\x01 \x01(\x0b\x32\'.yandex.cloud.ai.stt.v2.RecognitionSpec\x12\x11\n\tfolder_id\x18\x02 \x01(\t\"\x93\x03\n\x0fRecognitionSpec\x12M\n\x0e\x61udio_encoding\x18\x01 \x01(\x0e\x32\x35.yandex.cloud.ai.stt.v2.RecognitionSpec.AudioEncoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x03\x12\x15\n\rlanguage_code\x18\x03 \x01(\t\x12\x18\n\x10profanity_filter\x18\x04 \x01(\x08\x12\r\n\x05model\x18\x05 \x01(\t\x12\x17\n\x0fpartial_results\x18\x07 \x01(\x08\x12\x18\n\x10single_utterance\x18\x08 \x01(\x08\x12\x1b\n\x13\x61udio_channel_count\x18\t \x01(\x03\x12\x13\n\x0braw_results\x18\n \x01(\x08\x12\x17\n\x0fliterature_text\x18\x0b \x01(\x08\"X\n\rAudioEncoding\x12\x1e\n\x1a\x41UDIO_ENCODING_UNSPECIFIED\x10\x00\x12\x10\n\x0cLINEAR16_PCM\x10\x01\x12\x0c\n\x08OGG_OPUS\x10\x02\x12\x07\n\x03MP3\x10\x03\"\x8d\x01\n\x16SpeechRecognitionChunk\x12J\n\x0c\x61lternatives\x18\x01 \x03(\x0b\x32\x34.yandex.cloud.ai.stt.v2.SpeechRecognitionAlternative\x12\r\n\x05\x66inal\x18\x02 \x01(\x08\x12\x18\n\x10\x65nd_of_utterance\x18\x03 \x01(\x08\"z\n\x17SpeechRecognitionResult\x12J\n\x0c\x61lternatives\x18\x01 \x03(\x0b\x32\x34.yandex.cloud.ai.stt.v2.SpeechRecognitionAlternative\x12\x13\n\x0b\x63hannel_tag\x18\x02 \x01(\x03\"q\n\x1cSpeechRecognitionAlternative\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12/\n\x05words\x18\x03 \x03(\x0b\x32 .yandex.cloud.ai.stt.v2.WordInfo\"\x88\x01\n\x08WordInfo\x12-\n\nstart_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04word\x18\x03 \x01(\t\x12\x12\n\nconfidence\x18\x04 \x01(\x02\x32\xdb\x02\n\nSttService\x12\xc4\x01\n\x14LongRunningRecognize\x12\x35.yandex.cloud.ai.stt.v2.LongRunningRecognitionRequest\x1a!.yandex.cloud.operation.Operation\"R\x82\xd3\xe4\x93\x02(\"#/speech/stt/v2/longRunningRecognize:\x01*\xb2\xd2* \x12\x1eLongRunningRecognitionResponse\x12\x85\x01\n\x12StreamingRecognize\x12\x33.yandex.cloud.ai.stt.v2.StreamingRecognitionRequest\x1a\x34.yandex.cloud.ai.stt.v2.StreamingRecognitionResponse\"\x00(\x01\x30\x01\x42\\\n\x1ayandex.cloud.api.ai.stt.v2Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v2;sttb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,])



_RECOGNITIONSPEC_AUDIOENCODING = _descriptor.EnumDescriptor(
  name='AudioEncoding',
  full_name='yandex.cloud.ai.stt.v2.RecognitionSpec.AudioEncoding',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUDIO_ENCODING_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINEAR16_PCM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OGG_OPUS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MP3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1209,
  serialized_end=1297,
)
_sym_db.RegisterEnumDescriptor(_RECOGNITIONSPEC_AUDIOENCODING)


_LONGRUNNINGRECOGNITIONREQUEST = _descriptor.Descriptor(
  name='LongRunningRecognitionRequest',
  full_name='yandex.cloud.ai.stt.v2.LongRunningRecognitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.ai.stt.v2.LongRunningRecognitionRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio', full_name='yandex.cloud.ai.stt.v2.LongRunningRecognitionRequest.audio', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=352,
)


_LONGRUNNINGRECOGNITIONRESPONSE = _descriptor.Descriptor(
  name='LongRunningRecognitionResponse',
  full_name='yandex.cloud.ai.stt.v2.LongRunningRecognitionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chunks', full_name='yandex.cloud.ai.stt.v2.LongRunningRecognitionResponse.chunks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=451,
)


_STREAMINGRECOGNITIONREQUEST = _descriptor.Descriptor(
  name='StreamingRecognitionRequest',
  full_name='yandex.cloud.ai.stt.v2.StreamingRecognitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.ai.stt.v2.StreamingRecognitionRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_content', full_name='yandex.cloud.ai.stt.v2.StreamingRecognitionRequest.audio_content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streaming_request', full_name='yandex.cloud.ai.stt.v2.StreamingRecognitionRequest.streaming_request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=454,
  serialized_end=590,
)


_STREAMINGRECOGNITIONRESPONSE = _descriptor.Descriptor(
  name='StreamingRecognitionResponse',
  full_name='yandex.cloud.ai.stt.v2.StreamingRecognitionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chunks', full_name='yandex.cloud.ai.stt.v2.StreamingRecognitionResponse.chunks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=717,
)


_RECOGNITIONAUDIO = _descriptor.Descriptor(
  name='RecognitionAudio',
  full_name='yandex.cloud.ai.stt.v2.RecognitionAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='yandex.cloud.ai.stt.v2.RecognitionAudio.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='yandex.cloud.ai.stt.v2.RecognitionAudio.uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='audio_source', full_name='yandex.cloud.ai.stt.v2.RecognitionAudio.audio_source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=719,
  serialized_end=787,
)


_RECOGNITIONCONFIG = _descriptor.Descriptor(
  name='RecognitionConfig',
  full_name='yandex.cloud.ai.stt.v2.RecognitionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='specification', full_name='yandex.cloud.ai.stt.v2.RecognitionConfig.specification', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.ai.stt.v2.RecognitionConfig.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=789,
  serialized_end=891,
)


_RECOGNITIONSPEC = _descriptor.Descriptor(
  name='RecognitionSpec',
  full_name='yandex.cloud.ai.stt.v2.RecognitionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_encoding', full_name='yandex.cloud.ai.stt.v2.RecognitionSpec.audio_encoding', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_rate_hertz', full_name='yandex.cloud.ai.stt.v2.RecognitionSpec.sample_rate_hertz', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='yandex.cloud.ai.stt.v2.RecognitionSpec.language_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profanity_filter', full_name='yandex.cloud.ai.stt.v2.RecognitionSpec.profanity_filter', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='yandex.cloud.ai.stt.v2.RecognitionSpec.model', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partial_results', full_name='yandex.cloud.ai.stt.v2.RecognitionSpec.partial_results', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='single_utterance', full_name='yandex.cloud.ai.stt.v2.RecognitionSpec.single_utterance', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_channel_count', full_name='yandex.cloud.ai.stt.v2.RecognitionSpec.audio_channel_count', index=7,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_results', full_name='yandex.cloud.ai.stt.v2.RecognitionSpec.raw_results', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='literature_text', full_name='yandex.cloud.ai.stt.v2.RecognitionSpec.literature_text', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RECOGNITIONSPEC_AUDIOENCODING,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=894,
  serialized_end=1297,
)


_SPEECHRECOGNITIONCHUNK = _descriptor.Descriptor(
  name='SpeechRecognitionChunk',
  full_name='yandex.cloud.ai.stt.v2.SpeechRecognitionChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alternatives', full_name='yandex.cloud.ai.stt.v2.SpeechRecognitionChunk.alternatives', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='final', full_name='yandex.cloud.ai.stt.v2.SpeechRecognitionChunk.final', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_of_utterance', full_name='yandex.cloud.ai.stt.v2.SpeechRecognitionChunk.end_of_utterance', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1300,
  serialized_end=1441,
)


_SPEECHRECOGNITIONRESULT = _descriptor.Descriptor(
  name='SpeechRecognitionResult',
  full_name='yandex.cloud.ai.stt.v2.SpeechRecognitionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alternatives', full_name='yandex.cloud.ai.stt.v2.SpeechRecognitionResult.alternatives', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_tag', full_name='yandex.cloud.ai.stt.v2.SpeechRecognitionResult.channel_tag', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1565,
)


_SPEECHRECOGNITIONALTERNATIVE = _descriptor.Descriptor(
  name='SpeechRecognitionAlternative',
  full_name='yandex.cloud.ai.stt.v2.SpeechRecognitionAlternative',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='yandex.cloud.ai.stt.v2.SpeechRecognitionAlternative.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='yandex.cloud.ai.stt.v2.SpeechRecognitionAlternative.confidence', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='words', full_name='yandex.cloud.ai.stt.v2.SpeechRecognitionAlternative.words', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1680,
)


_WORDINFO = _descriptor.Descriptor(
  name='WordInfo',
  full_name='yandex.cloud.ai.stt.v2.WordInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time', full_name='yandex.cloud.ai.stt.v2.WordInfo.start_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='yandex.cloud.ai.stt.v2.WordInfo.end_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='word', full_name='yandex.cloud.ai.stt.v2.WordInfo.word', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='yandex.cloud.ai.stt.v2.WordInfo.confidence', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1683,
  serialized_end=1819,
)

_LONGRUNNINGRECOGNITIONREQUEST.fields_by_name['config'].message_type = _RECOGNITIONCONFIG
_LONGRUNNINGRECOGNITIONREQUEST.fields_by_name['audio'].message_type = _RECOGNITIONAUDIO
_LONGRUNNINGRECOGNITIONRESPONSE.fields_by_name['chunks'].message_type = _SPEECHRECOGNITIONRESULT
_STREAMINGRECOGNITIONREQUEST.fields_by_name['config'].message_type = _RECOGNITIONCONFIG
_STREAMINGRECOGNITIONREQUEST.oneofs_by_name['streaming_request'].fields.append(
  _STREAMINGRECOGNITIONREQUEST.fields_by_name['config'])
_STREAMINGRECOGNITIONREQUEST.fields_by_name['config'].containing_oneof = _STREAMINGRECOGNITIONREQUEST.oneofs_by_name['streaming_request']
_STREAMINGRECOGNITIONREQUEST.oneofs_by_name['streaming_request'].fields.append(
  _STREAMINGRECOGNITIONREQUEST.fields_by_name['audio_content'])
_STREAMINGRECOGNITIONREQUEST.fields_by_name['audio_content'].containing_oneof = _STREAMINGRECOGNITIONREQUEST.oneofs_by_name['streaming_request']
_STREAMINGRECOGNITIONRESPONSE.fields_by_name['chunks'].message_type = _SPEECHRECOGNITIONCHUNK
_RECOGNITIONAUDIO.oneofs_by_name['audio_source'].fields.append(
  _RECOGNITIONAUDIO.fields_by_name['content'])
_RECOGNITIONAUDIO.fields_by_name['content'].containing_oneof = _RECOGNITIONAUDIO.oneofs_by_name['audio_source']
_RECOGNITIONAUDIO.oneofs_by_name['audio_source'].fields.append(
  _RECOGNITIONAUDIO.fields_by_name['uri'])
_RECOGNITIONAUDIO.fields_by_name['uri'].containing_oneof = _RECOGNITIONAUDIO.oneofs_by_name['audio_source']
_RECOGNITIONCONFIG.fields_by_name['specification'].message_type = _RECOGNITIONSPEC
_RECOGNITIONSPEC.fields_by_name['audio_encoding'].enum_type = _RECOGNITIONSPEC_AUDIOENCODING
_RECOGNITIONSPEC_AUDIOENCODING.containing_type = _RECOGNITIONSPEC
_SPEECHRECOGNITIONCHUNK.fields_by_name['alternatives'].message_type = _SPEECHRECOGNITIONALTERNATIVE
_SPEECHRECOGNITIONRESULT.fields_by_name['alternatives'].message_type = _SPEECHRECOGNITIONALTERNATIVE
_SPEECHRECOGNITIONALTERNATIVE.fields_by_name['words'].message_type = _WORDINFO
_WORDINFO.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WORDINFO.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['LongRunningRecognitionRequest'] = _LONGRUNNINGRECOGNITIONREQUEST
DESCRIPTOR.message_types_by_name['LongRunningRecognitionResponse'] = _LONGRUNNINGRECOGNITIONRESPONSE
DESCRIPTOR.message_types_by_name['StreamingRecognitionRequest'] = _STREAMINGRECOGNITIONREQUEST
DESCRIPTOR.message_types_by_name['StreamingRecognitionResponse'] = _STREAMINGRECOGNITIONRESPONSE
DESCRIPTOR.message_types_by_name['RecognitionAudio'] = _RECOGNITIONAUDIO
DESCRIPTOR.message_types_by_name['RecognitionConfig'] = _RECOGNITIONCONFIG
DESCRIPTOR.message_types_by_name['RecognitionSpec'] = _RECOGNITIONSPEC
DESCRIPTOR.message_types_by_name['SpeechRecognitionChunk'] = _SPEECHRECOGNITIONCHUNK
DESCRIPTOR.message_types_by_name['SpeechRecognitionResult'] = _SPEECHRECOGNITIONRESULT
DESCRIPTOR.message_types_by_name['SpeechRecognitionAlternative'] = _SPEECHRECOGNITIONALTERNATIVE
DESCRIPTOR.message_types_by_name['WordInfo'] = _WORDINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LongRunningRecognitionRequest = _reflection.GeneratedProtocolMessageType('LongRunningRecognitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _LONGRUNNINGRECOGNITIONREQUEST,
  '__module__' : 'yandex.cloud.ai.stt.v2.stt_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.stt.v2.LongRunningRecognitionRequest)
  })
_sym_db.RegisterMessage(LongRunningRecognitionRequest)

LongRunningRecognitionResponse = _reflection.GeneratedProtocolMessageType('LongRunningRecognitionResponse', (_message.Message,), {
  'DESCRIPTOR' : _LONGRUNNINGRECOGNITIONRESPONSE,
  '__module__' : 'yandex.cloud.ai.stt.v2.stt_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.stt.v2.LongRunningRecognitionResponse)
  })
_sym_db.RegisterMessage(LongRunningRecognitionResponse)

StreamingRecognitionRequest = _reflection.GeneratedProtocolMessageType('StreamingRecognitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGRECOGNITIONREQUEST,
  '__module__' : 'yandex.cloud.ai.stt.v2.stt_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.stt.v2.StreamingRecognitionRequest)
  })
_sym_db.RegisterMessage(StreamingRecognitionRequest)

StreamingRecognitionResponse = _reflection.GeneratedProtocolMessageType('StreamingRecognitionResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGRECOGNITIONRESPONSE,
  '__module__' : 'yandex.cloud.ai.stt.v2.stt_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.stt.v2.StreamingRecognitionResponse)
  })
_sym_db.RegisterMessage(StreamingRecognitionResponse)

RecognitionAudio = _reflection.GeneratedProtocolMessageType('RecognitionAudio', (_message.Message,), {
  'DESCRIPTOR' : _RECOGNITIONAUDIO,
  '__module__' : 'yandex.cloud.ai.stt.v2.stt_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.stt.v2.RecognitionAudio)
  })
_sym_db.RegisterMessage(RecognitionAudio)

RecognitionConfig = _reflection.GeneratedProtocolMessageType('RecognitionConfig', (_message.Message,), {
  'DESCRIPTOR' : _RECOGNITIONCONFIG,
  '__module__' : 'yandex.cloud.ai.stt.v2.stt_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.stt.v2.RecognitionConfig)
  })
_sym_db.RegisterMessage(RecognitionConfig)

RecognitionSpec = _reflection.GeneratedProtocolMessageType('RecognitionSpec', (_message.Message,), {
  'DESCRIPTOR' : _RECOGNITIONSPEC,
  '__module__' : 'yandex.cloud.ai.stt.v2.stt_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.stt.v2.RecognitionSpec)
  })
_sym_db.RegisterMessage(RecognitionSpec)

SpeechRecognitionChunk = _reflection.GeneratedProtocolMessageType('SpeechRecognitionChunk', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHRECOGNITIONCHUNK,
  '__module__' : 'yandex.cloud.ai.stt.v2.stt_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.stt.v2.SpeechRecognitionChunk)
  })
_sym_db.RegisterMessage(SpeechRecognitionChunk)

SpeechRecognitionResult = _reflection.GeneratedProtocolMessageType('SpeechRecognitionResult', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHRECOGNITIONRESULT,
  '__module__' : 'yandex.cloud.ai.stt.v2.stt_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.stt.v2.SpeechRecognitionResult)
  })
_sym_db.RegisterMessage(SpeechRecognitionResult)

SpeechRecognitionAlternative = _reflection.GeneratedProtocolMessageType('SpeechRecognitionAlternative', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHRECOGNITIONALTERNATIVE,
  '__module__' : 'yandex.cloud.ai.stt.v2.stt_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.stt.v2.SpeechRecognitionAlternative)
  })
_sym_db.RegisterMessage(SpeechRecognitionAlternative)

WordInfo = _reflection.GeneratedProtocolMessageType('WordInfo', (_message.Message,), {
  'DESCRIPTOR' : _WORDINFO,
  '__module__' : 'yandex.cloud.ai.stt.v2.stt_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.stt.v2.WordInfo)
  })
_sym_db.RegisterMessage(WordInfo)


DESCRIPTOR._options = None

_STTSERVICE = _descriptor.ServiceDescriptor(
  name='SttService',
  full_name='yandex.cloud.ai.stt.v2.SttService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1822,
  serialized_end=2169,
  methods=[
  _descriptor.MethodDescriptor(
    name='LongRunningRecognize',
    full_name='yandex.cloud.ai.stt.v2.SttService.LongRunningRecognize',
    index=0,
    containing_service=None,
    input_type=_LONGRUNNINGRECOGNITIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002(\"#/speech/stt/v2/longRunningRecognize:\001*\262\322* \022\036LongRunningRecognitionResponse',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamingRecognize',
    full_name='yandex.cloud.ai.stt.v2.SttService.StreamingRecognize',
    index=1,
    containing_service=None,
    input_type=_STREAMINGRECOGNITIONREQUEST,
    output_type=_STREAMINGRECOGNITIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STTSERVICE)

DESCRIPTOR.services_by_name['SttService'] = _STTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/tts/v3/tts.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/tts/v3/tts.proto',
  package='speechkit.tts.v3',
  syntax='proto3',
  serialized_options=b'\n\032yandex.cloud.api.ai.tts.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/tts/v3;tts',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n yandex/cloud/ai/tts/v3/tts.proto\x12\x10speechkit.tts.v3\"j\n\x0c\x41udioContent\x12\x11\n\x07\x63ontent\x18\x01 \x01(\x0cH\x00\x12\x38\n\naudio_spec\x18\x02 \x01(\x0b\x32$.speechkit.tts.v3.AudioFormatOptionsB\r\n\x0b\x41udioSource\"\x91\x01\n\x12\x41udioFormatOptions\x12/\n\traw_audio\x18\x01 \x01(\x0b\x32\x1a.speechkit.tts.v3.RawAudioH\x00\x12;\n\x0f\x63ontainer_audio\x18\x02 \x01(\x0b\x32 .speechkit.tts.v3.ContainerAudioH\x00\x42\r\n\x0b\x41udioFormat\"\xaa\x01\n\x08RawAudio\x12@\n\x0e\x61udio_encoding\x18\x01 \x01(\x0e\x32(.speechkit.tts.v3.RawAudio.AudioEncoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x03\"A\n\rAudioEncoding\x12\x1e\n\x1a\x41UDIO_ENCODING_UNSPECIFIED\x10\x00\x12\x10\n\x0cLINEAR16_PCM\x10\x01\"\xbf\x01\n\x0e\x43ontainerAudio\x12Q\n\x14\x63ontainer_audio_type\x18\x01 \x01(\x0e\x32\x33.speechkit.tts.v3.ContainerAudio.ContainerAudioType\"Z\n\x12\x43ontainerAudioType\x12$\n CONTAINER_AUDIO_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03WAV\x10\x01\x12\x0c\n\x08OGG_OPUS\x10\x02\x12\x07\n\x03MP3\x10\x03\"=\n\x0cTextVariable\x12\x15\n\rvariable_name\x18\x01 \x01(\t\x12\x16\n\x0evariable_value\x18\x02 \x01(\t\"]\n\rAudioVariable\x12\x15\n\rvariable_name\x18\x01 \x01(\t\x12\x19\n\x11variable_start_ms\x18\x02 \x01(\x03\x12\x1a\n\x12variable_length_ms\x18\x03 \x01(\x03\"O\n\x1aUtteranceSynthesisResponse\x12\x31\n\x0b\x61udio_chunk\x18\x01 \x01(\x0b\x32\x1c.speechkit.tts.v3.AudioChunk\"\xa9\x01\n\rAudioTemplate\x12-\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1e.speechkit.tts.v3.AudioContent\x12\x35\n\rtext_template\x18\x02 \x01(\x0b\x32\x1e.speechkit.tts.v3.TextTemplate\x12\x32\n\tvariables\x18\x03 \x03(\x0b\x32\x1f.speechkit.tts.v3.AudioVariable\"\x1a\n\nAudioChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"X\n\x0cTextTemplate\x12\x15\n\rtext_template\x18\x01 \x01(\t\x12\x31\n\tvariables\x18\x02 \x03(\x0b\x32\x1e.speechkit.tts.v3.TextVariable\"\x8e\x01\n\x05Hints\x12\x0f\n\x05voice\x18\x01 \x01(\tH\x00\x12\x39\n\x0e\x61udio_template\x18\x02 \x01(\x0b\x32\x1f.speechkit.tts.v3.AudioTemplateH\x00\x12\x0f\n\x05speed\x18\x03 \x01(\x01H\x00\x12\x10\n\x06volume\x18\x04 \x01(\x01H\x00\x12\x0e\n\x04role\x18\x05 \x01(\tH\x00\x42\x06\n\x04Hint\"\xcc\x03\n\x19UtteranceSynthesisRequest\x12\r\n\x05model\x18\x01 \x01(\t\x12\x0e\n\x04text\x18\x02 \x01(\tH\x00\x12\x37\n\rtext_template\x18\x03 \x01(\x0b\x32\x1e.speechkit.tts.v3.TextTemplateH\x00\x12&\n\x05hints\x18\x04 \x03(\x0b\x32\x17.speechkit.tts.v3.Hints\x12?\n\x11output_audio_spec\x18\x05 \x01(\x0b\x32$.speechkit.tts.v3.AudioFormatOptions\x12j\n\x1bloudness_normalization_type\x18\x06 \x01(\x0e\x32\x45.speechkit.tts.v3.UtteranceSynthesisRequest.LoudnessNormalizationType\x12\x13\n\x0bunsafe_mode\x18\x07 \x01(\x08\"`\n\x19LoudnessNormalizationType\x12+\n\'LOUDNESS_NORMALIZATION_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08MAX_PEAK\x10\x01\x12\x08\n\x04LUFS\x10\x02\x42\x0b\n\tUtteranceB\\\n\x1ayandex.cloud.api.ai.tts.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/tts/v3;ttsb\x06proto3'
)



_RAWAUDIO_AUDIOENCODING = _descriptor.EnumDescriptor(
  name='AudioEncoding',
  full_name='speechkit.tts.v3.RawAudio.AudioEncoding',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUDIO_ENCODING_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINEAR16_PCM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=416,
  serialized_end=481,
)
_sym_db.RegisterEnumDescriptor(_RAWAUDIO_AUDIOENCODING)

_CONTAINERAUDIO_CONTAINERAUDIOTYPE = _descriptor.EnumDescriptor(
  name='ContainerAudioType',
  full_name='speechkit.tts.v3.ContainerAudio.ContainerAudioType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_AUDIO_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAV', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OGG_OPUS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MP3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=585,
  serialized_end=675,
)
_sym_db.RegisterEnumDescriptor(_CONTAINERAUDIO_CONTAINERAUDIOTYPE)

_UTTERANCESYNTHESISREQUEST_LOUDNESSNORMALIZATIONTYPE = _descriptor.EnumDescriptor(
  name='LoudnessNormalizationType',
  full_name='speechkit.tts.v3.UtteranceSynthesisRequest.LoudnessNormalizationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOUDNESS_NORMALIZATION_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_PEAK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LUFS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1703,
  serialized_end=1799,
)
_sym_db.RegisterEnumDescriptor(_UTTERANCESYNTHESISREQUEST_LOUDNESSNORMALIZATIONTYPE)


_AUDIOCONTENT = _descriptor.Descriptor(
  name='AudioContent',
  full_name='speechkit.tts.v3.AudioContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='speechkit.tts.v3.AudioContent.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_spec', full_name='speechkit.tts.v3.AudioContent.audio_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='AudioSource', full_name='speechkit.tts.v3.AudioContent.AudioSource',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=54,
  serialized_end=160,
)


_AUDIOFORMATOPTIONS = _descriptor.Descriptor(
  name='AudioFormatOptions',
  full_name='speechkit.tts.v3.AudioFormatOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_audio', full_name='speechkit.tts.v3.AudioFormatOptions.raw_audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='container_audio', full_name='speechkit.tts.v3.AudioFormatOptions.container_audio', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='AudioFormat', full_name='speechkit.tts.v3.AudioFormatOptions.AudioFormat',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=163,
  serialized_end=308,
)


_RAWAUDIO = _descriptor.Descriptor(
  name='RawAudio',
  full_name='speechkit.tts.v3.RawAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_encoding', full_name='speechkit.tts.v3.RawAudio.audio_encoding', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_rate_hertz', full_name='speechkit.tts.v3.RawAudio.sample_rate_hertz', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RAWAUDIO_AUDIOENCODING,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=481,
)


_CONTAINERAUDIO = _descriptor.Descriptor(
  name='ContainerAudio',
  full_name='speechkit.tts.v3.ContainerAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_audio_type', full_name='speechkit.tts.v3.ContainerAudio.container_audio_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONTAINERAUDIO_CONTAINERAUDIOTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=484,
  serialized_end=675,
)


_TEXTVARIABLE = _descriptor.Descriptor(
  name='TextVariable',
  full_name='speechkit.tts.v3.TextVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable_name', full_name='speechkit.tts.v3.TextVariable.variable_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable_value', full_name='speechkit.tts.v3.TextVariable.variable_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=677,
  serialized_end=738,
)


_AUDIOVARIABLE = _descriptor.Descriptor(
  name='AudioVariable',
  full_name='speechkit.tts.v3.AudioVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable_name', full_name='speechkit.tts.v3.AudioVariable.variable_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable_start_ms', full_name='speechkit.tts.v3.AudioVariable.variable_start_ms', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable_length_ms', full_name='speechkit.tts.v3.AudioVariable.variable_length_ms', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=740,
  serialized_end=833,
)


_UTTERANCESYNTHESISRESPONSE = _descriptor.Descriptor(
  name='UtteranceSynthesisResponse',
  full_name='speechkit.tts.v3.UtteranceSynthesisResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_chunk', full_name='speechkit.tts.v3.UtteranceSynthesisResponse.audio_chunk', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=835,
  serialized_end=914,
)


_AUDIOTEMPLATE = _descriptor.Descriptor(
  name='AudioTemplate',
  full_name='speechkit.tts.v3.AudioTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio', full_name='speechkit.tts.v3.AudioTemplate.audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_template', full_name='speechkit.tts.v3.AudioTemplate.text_template', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='speechkit.tts.v3.AudioTemplate.variables', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=917,
  serialized_end=1086,
)


_AUDIOCHUNK = _descriptor.Descriptor(
  name='AudioChunk',
  full_name='speechkit.tts.v3.AudioChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='speechkit.tts.v3.AudioChunk.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1088,
  serialized_end=1114,
)


_TEXTTEMPLATE = _descriptor.Descriptor(
  name='TextTemplate',
  full_name='speechkit.tts.v3.TextTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text_template', full_name='speechkit.tts.v3.TextTemplate.text_template', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='speechkit.tts.v3.TextTemplate.variables', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1116,
  serialized_end=1204,
)


_HINTS = _descriptor.Descriptor(
  name='Hints',
  full_name='speechkit.tts.v3.Hints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice', full_name='speechkit.tts.v3.Hints.voice', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_template', full_name='speechkit.tts.v3.Hints.audio_template', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='speechkit.tts.v3.Hints.speed', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='speechkit.tts.v3.Hints.volume', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='speechkit.tts.v3.Hints.role', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Hint', full_name='speechkit.tts.v3.Hints.Hint',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1207,
  serialized_end=1349,
)


_UTTERANCESYNTHESISREQUEST = _descriptor.Descriptor(
  name='UtteranceSynthesisRequest',
  full_name='speechkit.tts.v3.UtteranceSynthesisRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='speechkit.tts.v3.UtteranceSynthesisRequest.model', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='speechkit.tts.v3.UtteranceSynthesisRequest.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_template', full_name='speechkit.tts.v3.UtteranceSynthesisRequest.text_template', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hints', full_name='speechkit.tts.v3.UtteranceSynthesisRequest.hints', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_audio_spec', full_name='speechkit.tts.v3.UtteranceSynthesisRequest.output_audio_spec', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loudness_normalization_type', full_name='speechkit.tts.v3.UtteranceSynthesisRequest.loudness_normalization_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsafe_mode', full_name='speechkit.tts.v3.UtteranceSynthesisRequest.unsafe_mode', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UTTERANCESYNTHESISREQUEST_LOUDNESSNORMALIZATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Utterance', full_name='speechkit.tts.v3.UtteranceSynthesisRequest.Utterance',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1352,
  serialized_end=1812,
)

_AUDIOCONTENT.fields_by_name['audio_spec'].message_type = _AUDIOFORMATOPTIONS
_AUDIOCONTENT.oneofs_by_name['AudioSource'].fields.append(
  _AUDIOCONTENT.fields_by_name['content'])
_AUDIOCONTENT.fields_by_name['content'].containing_oneof = _AUDIOCONTENT.oneofs_by_name['AudioSource']
_AUDIOFORMATOPTIONS.fields_by_name['raw_audio'].message_type = _RAWAUDIO
_AUDIOFORMATOPTIONS.fields_by_name['container_audio'].message_type = _CONTAINERAUDIO
_AUDIOFORMATOPTIONS.oneofs_by_name['AudioFormat'].fields.append(
  _AUDIOFORMATOPTIONS.fields_by_name['raw_audio'])
_AUDIOFORMATOPTIONS.fields_by_name['raw_audio'].containing_oneof = _AUDIOFORMATOPTIONS.oneofs_by_name['AudioFormat']
_AUDIOFORMATOPTIONS.oneofs_by_name['AudioFormat'].fields.append(
  _AUDIOFORMATOPTIONS.fields_by_name['container_audio'])
_AUDIOFORMATOPTIONS.fields_by_name['container_audio'].containing_oneof = _AUDIOFORMATOPTIONS.oneofs_by_name['AudioFormat']
_RAWAUDIO.fields_by_name['audio_encoding'].enum_type = _RAWAUDIO_AUDIOENCODING
_RAWAUDIO_AUDIOENCODING.containing_type = _RAWAUDIO
_CONTAINERAUDIO.fields_by_name['container_audio_type'].enum_type = _CONTAINERAUDIO_CONTAINERAUDIOTYPE
_CONTAINERAUDIO_CONTAINERAUDIOTYPE.containing_type = _CONTAINERAUDIO
_UTTERANCESYNTHESISRESPONSE.fields_by_name['audio_chunk'].message_type = _AUDIOCHUNK
_AUDIOTEMPLATE.fields_by_name['audio'].message_type = _AUDIOCONTENT
_AUDIOTEMPLATE.fields_by_name['text_template'].message_type = _TEXTTEMPLATE
_AUDIOTEMPLATE.fields_by_name['variables'].message_type = _AUDIOVARIABLE
_TEXTTEMPLATE.fields_by_name['variables'].message_type = _TEXTVARIABLE
_HINTS.fields_by_name['audio_template'].message_type = _AUDIOTEMPLATE
_HINTS.oneofs_by_name['Hint'].fields.append(
  _HINTS.fields_by_name['voice'])
_HINTS.fields_by_name['voice'].containing_oneof = _HINTS.oneofs_by_name['Hint']
_HINTS.oneofs_by_name['Hint'].fields.append(
  _HINTS.fields_by_name['audio_template'])
_HINTS.fields_by_name['audio_template'].containing_oneof = _HINTS.oneofs_by_name['Hint']
_HINTS.oneofs_by_name['Hint'].fields.append(
  _HINTS.fields_by_name['speed'])
_HINTS.fields_by_name['speed'].containing_oneof = _HINTS.oneofs_by_name['Hint']
_HINTS.oneofs_by_name['Hint'].fields.append(
  _HINTS.fields_by_name['volume'])
_HINTS.fields_by_name['volume'].containing_oneof = _HINTS.oneofs_by_name['Hint']
_HINTS.oneofs_by_name['Hint'].fields.append(
  _HINTS.fields_by_name['role'])
_HINTS.fields_by_name['role'].containing_oneof = _HINTS.oneofs_by_name['Hint']
_UTTERANCESYNTHESISREQUEST.fields_by_name['text_template'].message_type = _TEXTTEMPLATE
_UTTERANCESYNTHESISREQUEST.fields_by_name['hints'].message_type = _HINTS
_UTTERANCESYNTHESISREQUEST.fields_by_name['output_audio_spec'].message_type = _AUDIOFORMATOPTIONS
_UTTERANCESYNTHESISREQUEST.fields_by_name['loudness_normalization_type'].enum_type = _UTTERANCESYNTHESISREQUEST_LOUDNESSNORMALIZATIONTYPE
_UTTERANCESYNTHESISREQUEST_LOUDNESSNORMALIZATIONTYPE.containing_type = _UTTERANCESYNTHESISREQUEST
_UTTERANCESYNTHESISREQUEST.oneofs_by_name['Utterance'].fields.append(
  _UTTERANCESYNTHESISREQUEST.fields_by_name['text'])
_UTTERANCESYNTHESISREQUEST.fields_by_name['text'].containing_oneof = _UTTERANCESYNTHESISREQUEST.oneofs_by_name['Utterance']
_UTTERANCESYNTHESISREQUEST.oneofs_by_name['Utterance'].fields.append(
  _UTTERANCESYNTHESISREQUEST.fields_by_name['text_template'])
_UTTERANCESYNTHESISREQUEST.fields_by_name['text_template'].containing_oneof = _UTTERANCESYNTHESISREQUEST.oneofs_by_name['Utterance']
DESCRIPTOR.message_types_by_name['AudioContent'] = _AUDIOCONTENT
DESCRIPTOR.message_types_by_name['AudioFormatOptions'] = _AUDIOFORMATOPTIONS
DESCRIPTOR.message_types_by_name['RawAudio'] = _RAWAUDIO
DESCRIPTOR.message_types_by_name['ContainerAudio'] = _CONTAINERAUDIO
DESCRIPTOR.message_types_by_name['TextVariable'] = _TEXTVARIABLE
DESCRIPTOR.message_types_by_name['AudioVariable'] = _AUDIOVARIABLE
DESCRIPTOR.message_types_by_name['UtteranceSynthesisResponse'] = _UTTERANCESYNTHESISRESPONSE
DESCRIPTOR.message_types_by_name['AudioTemplate'] = _AUDIOTEMPLATE
DESCRIPTOR.message_types_by_name['AudioChunk'] = _AUDIOCHUNK
DESCRIPTOR.message_types_by_name['TextTemplate'] = _TEXTTEMPLATE
DESCRIPTOR.message_types_by_name['Hints'] = _HINTS
DESCRIPTOR.message_types_by_name['UtteranceSynthesisRequest'] = _UTTERANCESYNTHESISREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioContent = _reflection.GeneratedProtocolMessageType('AudioContent', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOCONTENT,
  '__module__' : 'yandex.cloud.ai.tts.v3.tts_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.tts.v3.AudioContent)
  })
_sym_db.RegisterMessage(AudioContent)

AudioFormatOptions = _reflection.GeneratedProtocolMessageType('AudioFormatOptions', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOFORMATOPTIONS,
  '__module__' : 'yandex.cloud.ai.tts.v3.tts_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.tts.v3.AudioFormatOptions)
  })
_sym_db.RegisterMessage(AudioFormatOptions)

RawAudio = _reflection.GeneratedProtocolMessageType('RawAudio', (_message.Message,), {
  'DESCRIPTOR' : _RAWAUDIO,
  '__module__' : 'yandex.cloud.ai.tts.v3.tts_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.tts.v3.RawAudio)
  })
_sym_db.RegisterMessage(RawAudio)

ContainerAudio = _reflection.GeneratedProtocolMessageType('ContainerAudio', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERAUDIO,
  '__module__' : 'yandex.cloud.ai.tts.v3.tts_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.tts.v3.ContainerAudio)
  })
_sym_db.RegisterMessage(ContainerAudio)

TextVariable = _reflection.GeneratedProtocolMessageType('TextVariable', (_message.Message,), {
  'DESCRIPTOR' : _TEXTVARIABLE,
  '__module__' : 'yandex.cloud.ai.tts.v3.tts_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.tts.v3.TextVariable)
  })
_sym_db.RegisterMessage(TextVariable)

AudioVariable = _reflection.GeneratedProtocolMessageType('AudioVariable', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOVARIABLE,
  '__module__' : 'yandex.cloud.ai.tts.v3.tts_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.tts.v3.AudioVariable)
  })
_sym_db.RegisterMessage(AudioVariable)

UtteranceSynthesisResponse = _reflection.GeneratedProtocolMessageType('UtteranceSynthesisResponse', (_message.Message,), {
  'DESCRIPTOR' : _UTTERANCESYNTHESISRESPONSE,
  '__module__' : 'yandex.cloud.ai.tts.v3.tts_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.tts.v3.UtteranceSynthesisResponse)
  })
_sym_db.RegisterMessage(UtteranceSynthesisResponse)

AudioTemplate = _reflection.GeneratedProtocolMessageType('AudioTemplate', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOTEMPLATE,
  '__module__' : 'yandex.cloud.ai.tts.v3.tts_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.tts.v3.AudioTemplate)
  })
_sym_db.RegisterMessage(AudioTemplate)

AudioChunk = _reflection.GeneratedProtocolMessageType('AudioChunk', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOCHUNK,
  '__module__' : 'yandex.cloud.ai.tts.v3.tts_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.tts.v3.AudioChunk)
  })
_sym_db.RegisterMessage(AudioChunk)

TextTemplate = _reflection.GeneratedProtocolMessageType('TextTemplate', (_message.Message,), {
  'DESCRIPTOR' : _TEXTTEMPLATE,
  '__module__' : 'yandex.cloud.ai.tts.v3.tts_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.tts.v3.TextTemplate)
  })
_sym_db.RegisterMessage(TextTemplate)

Hints = _reflection.GeneratedProtocolMessageType('Hints', (_message.Message,), {
  'DESCRIPTOR' : _HINTS,
  '__module__' : 'yandex.cloud.ai.tts.v3.tts_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.tts.v3.Hints)
  })
_sym_db.RegisterMessage(Hints)

UtteranceSynthesisRequest = _reflection.GeneratedProtocolMessageType('UtteranceSynthesisRequest', (_message.Message,), {
  'DESCRIPTOR' : _UTTERANCESYNTHESISREQUEST,
  '__module__' : 'yandex.cloud.ai.tts.v3.tts_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.tts.v3.UtteranceSynthesisRequest)
  })
_sym_db.RegisterMessage(UtteranceSynthesisRequest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.ai.stt.v3 import stt_pb2 as yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2


class RecognizerStub(object):
    """A set of methods for voice recognition.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RecognizeStreaming = channel.stream_stream(
                '/speechkit.stt.v3.Recognizer/RecognizeStreaming',
                request_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingResponse.FromString,
                )


class RecognizerServicer(object):
    """A set of methods for voice recognition.
    """

    def RecognizeStreaming(self, request_iterator, context):
        """Expects audio in real-time
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RecognizerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RecognizeStreaming': grpc.stream_stream_rpc_method_handler(
                    servicer.RecognizeStreaming,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'speechkit.stt.v3.Recognizer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Recognizer(object):
    """A set of methods for voice recognition.
    """

    @staticmethod
    def RecognizeStreaming(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/speechkit.stt.v3.Recognizer/RecognizeStreaming',
            yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/vision/v2/image_classifier_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.vision.v2 import image_classifier_pb2 as yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__classifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/vision/v2/image_classifier_service.proto',
  package='yandex.cloud.ai.vision.v2',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;vision',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8yandex/cloud/ai/vision/v2/image_classifier_service.proto\x12\x19yandex.cloud.ai.vision.v2\x1a\x30yandex/cloud/ai/vision/v2/image_classifier.proto2\x83\x01\n\x16ImageClassifierService\x12i\n\x08\x41nnotate\x12,.yandex.cloud.ai.vision.v2.AnnotationRequest\x1a-.yandex.cloud.ai.vision.v2.AnnotationResponse\"\x00\x42\x65\n\x1dyandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;visionb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__classifier__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_IMAGECLASSIFIERSERVICE = _descriptor.ServiceDescriptor(
  name='ImageClassifierService',
  full_name='yandex.cloud.ai.vision.v2.ImageClassifierService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=138,
  serialized_end=269,
  methods=[
  _descriptor.MethodDescriptor(
    name='Annotate',
    full_name='yandex.cloud.ai.vision.v2.ImageClassifierService.Annotate',
    index=0,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__classifier__pb2._ANNOTATIONREQUEST,
    output_type=yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__classifier__pb2._ANNOTATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_IMAGECLASSIFIERSERVICE)

DESCRIPTOR.services_by_name['ImageClassifierService'] = _IMAGECLASSIFIERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mongodb/v1/resource_preset.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/mongodb/v1/resource_preset.proto',
  package='yandex.cloud.mdb.mongodb.v1',
  syntax='proto3',
  serialized_options=b'\n\037yandex.cloud.api.mdb.mongodb.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1;mongodb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/mdb/mongodb/v1/resource_preset.proto\x12\x1byandex.cloud.mdb.mongodb.v1\"M\n\x0eResourcePreset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08zone_ids\x18\x02 \x03(\t\x12\r\n\x05\x63ores\x18\x03 \x01(\x03\x12\x0e\n\x06memory\x18\x04 \x01(\x03\x42j\n\x1fyandex.cloud.api.mdb.mongodb.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1;mongodbb\x06proto3'
)




_RESOURCEPRESET = _descriptor.Descriptor(
  name='ResourcePreset',
  full_name='yandex.cloud.mdb.mongodb.v1.ResourcePreset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.mdb.mongodb.v1.ResourcePreset.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_ids', full_name='yandex.cloud.mdb.mongodb.v1.ResourcePreset.zone_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cores', full_name='yandex.cloud.mdb.mongodb.v1.ResourcePreset.cores', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory', full_name='yandex.cloud.mdb.mongodb.v1.ResourcePreset.memory', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=159,
)

DESCRIPTOR.message_types_by_name['ResourcePreset'] = _RESOURCEPRESET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ResourcePreset = _reflection.GeneratedProtocolMessageType('ResourcePreset', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEPRESET,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.resource_preset_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.ResourcePreset)
  })
_sym_db.RegisterMessage(ResourcePreset)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/sku.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/billing/v1/sku.proto',
  package='yandex.cloud.billing.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!yandex/cloud/billing/v1/sku.proto\x12\x17yandex.cloud.billing.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa1\x01\n\x03Sku\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nservice_id\x18\x04 \x01(\t\x12\x14\n\x0cpricing_unit\x18\x05 \x01(\t\x12\x41\n\x10pricing_versions\x18\x06 \x03(\x0b\x32\'.yandex.cloud.billing.v1.PricingVersion\"\xc8\x01\n\x0ePricingVersion\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.yandex.cloud.billing.v1.PricingVersionType\x12\x32\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x13pricing_expressions\x18\x03 \x03(\x0b\x32*.yandex.cloud.billing.v1.PricingExpression\"A\n\x11PricingExpression\x12,\n\x05rates\x18\x02 \x03(\x0b\x32\x1d.yandex.cloud.billing.v1.Rate\"L\n\x04Rate\x12\x1e\n\x16start_pricing_quantity\x18\x01 \x01(\t\x12\x12\n\nunit_price\x18\x02 \x01(\t\x12\x10\n\x08\x63urrency\x18\x03 \x01(\t*`\n\x12PricingVersionType\x12$\n PRICING_VERSION_TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cSTREET_PRICE\x10\x01\x12\x12\n\x0e\x43ONTRACT_PRICE\x10\x02\x42\x62\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_PRICINGVERSIONTYPE = _descriptor.EnumDescriptor(
  name='PricingVersionType',
  full_name='yandex.cloud.billing.v1.PricingVersionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRICING_VERSION_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STREET_PRICE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTRACT_PRICE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=607,
  serialized_end=703,
)
_sym_db.RegisterEnumDescriptor(_PRICINGVERSIONTYPE)

PricingVersionType = enum_type_wrapper.EnumTypeWrapper(_PRICINGVERSIONTYPE)
PRICING_VERSION_TYPE_UNSPECIFIED = 0
STREET_PRICE = 1
CONTRACT_PRICE = 2



_SKU = _descriptor.Descriptor(
  name='Sku',
  full_name='yandex.cloud.billing.v1.Sku',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.billing.v1.Sku.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.billing.v1.Sku.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.billing.v1.Sku.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_id', full_name='yandex.cloud.billing.v1.Sku.service_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pricing_unit', full_name='yandex.cloud.billing.v1.Sku.pricing_unit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pricing_versions', full_name='yandex.cloud.billing.v1.Sku.pricing_versions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=257,
)


_PRICINGVERSION = _descriptor.Descriptor(
  name='PricingVersion',
  full_name='yandex.cloud.billing.v1.PricingVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.billing.v1.PricingVersion.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effective_time', full_name='yandex.cloud.billing.v1.PricingVersion.effective_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pricing_expressions', full_name='yandex.cloud.billing.v1.PricingVersion.pricing_expressions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=460,
)


_PRICINGEXPRESSION = _descriptor.Descriptor(
  name='PricingExpression',
  full_name='yandex.cloud.billing.v1.PricingExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rates', full_name='yandex.cloud.billing.v1.PricingExpression.rates', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=527,
)


_RATE = _descriptor.Descriptor(
  name='Rate',
  full_name='yandex.cloud.billing.v1.Rate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_pricing_quantity', full_name='yandex.cloud.billing.v1.Rate.start_pricing_quantity', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_price', full_name='yandex.cloud.billing.v1.Rate.unit_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='yandex.cloud.billing.v1.Rate.currency', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=605,
)

_SKU.fields_by_name['pricing_versions'].message_type = _PRICINGVERSION
_PRICINGVERSION.fields_by_name['type'].enum_type = _PRICINGVERSIONTYPE
_PRICINGVERSION.fields_by_name['effective_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PRICINGVERSION.fields_by_name['pricing_expressions'].message_type = _PRICINGEXPRESSION
_PRICINGEXPRESSION.fields_by_name['rates'].message_type = _RATE
DESCRIPTOR.message_types_by_name['Sku'] = _SKU
DESCRIPTOR.message_types_by_name['PricingVersion'] = _PRICINGVERSION
DESCRIPTOR.message_types_by_name['PricingExpression'] = _PRICINGEXPRESSION
DESCRIPTOR.message_types_by_name['Rate'] = _RATE
DESCRIPTOR.enum_types_by_name['PricingVersionType'] = _PRICINGVERSIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Sku = _reflection.GeneratedProtocolMessageType('Sku', (_message.Message,), {
  'DESCRIPTOR' : _SKU,
  '__module__' : 'yandex.cloud.billing.v1.sku_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.Sku)
  })
_sym_db.RegisterMessage(Sku)

PricingVersion = _reflection.GeneratedProtocolMessageType('PricingVersion', (_message.Message,), {
  'DESCRIPTOR' : _PRICINGVERSION,
  '__module__' : 'yandex.cloud.billing.v1.sku_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.PricingVersion)
  })
_sym_db.RegisterMessage(PricingVersion)

PricingExpression = _reflection.GeneratedProtocolMessageType('PricingExpression', (_message.Message,), {
  'DESCRIPTOR' : _PRICINGEXPRESSION,
  '__module__' : 'yandex.cloud.billing.v1.sku_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.PricingExpression)
  })
_sym_db.RegisterMessage(PricingExpression)

Rate = _reflection.GeneratedProtocolMessageType('Rate', (_message.Message,), {
  'DESCRIPTOR' : _RATE,
  '__module__' : 'yandex.cloud.billing.v1.sku_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.Rate)
  })
_sym_db.RegisterMessage(Rate)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
